==> dde-launcher_4.4.5.5.orig.tar.xz: dde-launcher-4.4.5.5/translations/dde-launcher_it.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="it" version="2.1">
<context>
    <name>AppsManager</name>
    <message>
        <source>No search results</source>
        <translation>Nessun risultato</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Chat</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Music</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Video</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Graphics</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Game</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Office</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reading</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Development</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>System</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Others</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FullScreenFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation>Sicuro di voler disinstallare %1 ?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Conferma</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Remove from desktop</source>
        <translation>Rimuovi dal desktop</translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation>Rimuovi dalla dock</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>Disinstalla</translation>
    </message>
    <message>
        <source>Open by proxy</source>
        <translation>Apri via proxy</translation>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation>Disabilita scaling del display</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Apri</translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation>Invia al desktop</translation>
    </message>
    <message>
        <source>Send to dock</source>
        <translation>Invia alla dock</translation>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation>Rimuovi dall&apos;avvio automatico</translation>
    </message>
    <message>
        <source>Add to startup</source>
        <translation>Aggiungi all&apos;avvio automatico</translation>
    </message>
</context>
<context>
    <name>MiniCategoryWidget</name>
    <message>
        <source>All Apps</source>
        <translation>Tutte le app</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musica</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Grafica</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Giochi</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Ufficio</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Lettura</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Sviluppo</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>Altro</translation>
    </message>
</context>
<context>
    <name>MiniFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation>Sicuro di voler disinstallare %1 ?</translation>
    </message>
    <message>
        <source>All dependencies will be removed together</source>
        <translation>Tutte le dipendenze saranno eliminate</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Conferma</translation>
    </message>
</context>
<context>
    <name>MiniFrameBottomBar</name>
    <message>
        <source>Computer</source>
        <translation>Computer</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Documenti</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musica</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Immagini</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Download</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Blocca</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Logout</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Riavvia</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Sospendi</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Spegni</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Indietro</translation>
    </message>
</context>
<context>
    <name>MiniFrameNavigation</name>
    <message>
        <source>Computer</source>
        <translation>Computer</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musica</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Spegni</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Blocca</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Logout</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Riavvia</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Sospendi</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Indietro</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Documenti</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Immagini</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Download</translation>
    </message>
</context>
<context>
    <name>MiniFrameRightBar</name>
    <message>
        <source>Computer</source>
        <translation>Computer</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musica</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Download</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuale</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Impostazioni</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Spegni</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Immagini</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Documenti</translation>
    </message>
</context>
<context>
    <name>MiniFrameSwitchBtn</name>
    <message>
        <source>All Categories</source>
        <translation>Tutte le categorie</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Indietro</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation>Sicuro di voler disinstallare %1 ?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Conferma</translation>
    </message>
</context>
</TS>

==> dde-launcher_4.6.13.orig.tar.xz: dde-launcher-4.6.13/translations/dde-launcher_it.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="it" version="2.1">
<context>
    <name>AppsManager</name>
    <message>
        <source>No search results</source>
        <translation>Nessun risultato</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musica</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Grafica</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Ufficio</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Lettura</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Sviluppo</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <source>Games</source>
        <translation>Giochi</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Altro</translation>
    </message>
</context>
<context>
    <name>FullScreenFrame</name>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Conferma</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall %1 ?</source>
        <translation>Sicuro di voler disinstallare %1 ?</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Remove from desktop</source>
        <translation>Rimuovi dal desktop</translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation>Rimuovi dalla dock</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>Disinstalla</translation>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation>Disabilita scaling del display</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Apri</translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation>Invia al desktop</translation>
    </message>
    <message>
        <source>Send to dock</source>
        <translation>Invia alla dock</translation>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation>Rimuovi dall&apos;avvio automatico</translation>
    </message>
    <message>
        <source>Add to startup</source>
        <translation>Aggiungi all&apos;avvio automatico</translation>
    </message>
    <message>
        <source>Use a proxy</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniCategoryWidget</name>
    <message>
        <source>All Apps</source>
        <translation>Tutte le app</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musica</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Grafica</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Giochi</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Ufficio</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Lettura</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Sviluppo</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>Altro</translation>
    </message>
</context>
<context>
    <name>MiniFrameBottomBar</name>
    <message>
        <source>Computer</source>
        <translation>Computer</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Documenti</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musica</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Immagini</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Download</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Blocca</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Logout</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Riavvia</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Sospendi</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Spegni</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Indietro</translation>
    </message>
</context>
<context>
    <name>MiniFrameNavigation</name>
    <message>
        <source>Computer</source>
        <translation>Computer</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musica</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Spegni</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Blocca</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Logout</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Riavvia</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Sospendi</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Indietro</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Documenti</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Immagini</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Download</translation>
    </message>
</context>
<context>
    <name>MiniFrameRightBar</name>
    <message>
        <source>Computer</source>
        <translation>Computer</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musica</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Download</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuale</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Impostazioni</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Immagini</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Documenti</translation>
    </message>
    <message>
        <source>Power</source>
        <translation>Alimentazione</translation>
    </message>
</context>
<context>
    <name>MiniFrameSwitchBtn</name>
    <message>
        <source>All Categories</source>
        <translation>Tutte le categorie</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Indietro</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Conferma</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall %1 ?</source>
        <translation>Sicuro di voler disinstallare %1 ?</translation>
    </message>
</context>
</TS>
